@@ -381,8 +381,8 @@ def load_completion_for(bash: pexpect.spawn, cmd: str) -> bool:
     try:
         # Allow _comp_load to fail so we can test completions
         # that are directly loaded in bash_completion without a separate file.
-        assert_bash_exec(bash, "_comp_load %s || :" % cmd)
-        assert_bash_exec(bash, "complete -p %s &>/dev/null" % cmd)
+        assert_bash_exec(bash, "_comp_load -- %s || :" % cmd)
+        assert_bash_exec(bash, "complete -p -- %s &>/dev/null" % cmd)
     except AssertionError:
         return False
     return True
@@ -665,7 +665,7 @@ class bash_env_saved:
     def set(self, name: str, value: bool):
         self._unprotect_set(name)
         if value:
-            self._safe_exec("set -u %s" % name)
+            self._safe_exec("set -o %s" % name)
         else:
             self._safe_exec("set +o %s" % name)
         self._protect_set(name)
