@@ -6,7 +6,7 @@ class TestGpgv:
     def test_1(self, completion):
         assert completion
 
-    @pytest.mark.complete("gpgv -")
+    @pytest.mark.complete("gpgv -", require_cmd=True)
     def test_2(self, completion):
         assert completion
 
