@@ -3,7 +3,9 @@ import pytest
 
 class TestLvmdiskscan:
     @pytest.mark.complete(
-        "lvmdiskscan --", skipif="! lvmdiskscan --help &>/dev/null"
+        "lvmdiskscan --",
+        require_cmd=True,
+        xfail="! lvmdiskscan --help &>/dev/null",
     )
     def test_1(self, completion):
         assert completion
