@@ -1,10 +1,12 @@
 import pytest
 
+from conftest import assert_complete
+
 
 class TestUlimit:
     @pytest.mark.complete("ulimit ")
     def test_1(self, completion):
-        assert completion
+        assert not completion
 
     @pytest.mark.complete("ulimit -", require_cmd=True)
     def test_2(self, completion):
@@ -33,3 +35,13 @@ class TestUlimit:
     def test_7(self, completion):
         """Test modes are NOT completed with -a given somewhere."""
         assert not completion
+
+    @pytest.mark.parametrize("flag", ["-S", "-H"])
+    def test_no_special_values_after_soft_or_hard(self, bash, flag):
+        completion = assert_complete(bash, "ulimit %s " % flag)
+        assert not completion
+
+    @pytest.mark.complete("ulimit -c 0 -n ")
+    def test_special_not_just_first(self, completion):
+        """Test we offer limit values not only for the first option."""
+        assert completion
